@@ -15,6 +15,7 @@ class ConfigManagerCaller(CallerBase):
     def __init__(self, app_id):
         super().__init__(app_id)
         self.app_id = app_id
+        self.update_robot_config_url = "{}/api/v1/robot/config".format(Config.base_url)
         # 获取预设话术url
         self.get_default_response_url = "{}/api/v2/robot/chats".format(Config.base_url)
         self.backfill_answer_url = "{}/api/v2/robot/chat/3/content".format(Config.base_url)
@@ -46,6 +47,20 @@ class ConfigManagerCaller(CallerBase):
             msg = "Exception When GET '{}' : {}".format(self.get_default_response_url, traceback.format_exc())
             logging.error('configManager: 初始化机器人失败， 原因：' + msg)
 
+    def update_robot_config(self, config_key: str, value):
+        try:
+            response = requests.post(url=self.update_robot_config_url, headers=self.header, files={
+                'configName': (None, config_key),
+                'module': (None, 'controller'),
+                'value': (None, value)
+            })
+            if self._response_failed(response):
+                logging.error(
+                    "configManager: 更新配置失败: 接口异常。" + str(response.json()) if response is not None else '')
+        except Exception:
+            msg = "Exception When GET '{}' : {}".format(self.update_robot_config_url, traceback.format_exc())
+            logging.error('configManager: 更新配置失败， 原因：' + msg)
+
     def get_backfill(self):
         try:
             response = requests.get(url=self.get_default_response_url, headers=self.header)
@@ -79,3 +94,10 @@ class ConfigManagerCaller(CallerBase):
             msg = "Exception When GET '{}' : {}".format(self.get_default_response_url, traceback.format_exc())
             logging.error('configManager: 设置未知回复话术失败， 原因：' + msg)
             return False
+
+    def set_profess(self, profess: str):
+        """
+        设置机器人自称
+        :param profess: 自称
+        :return:
+        """
