@@ -20,9 +20,12 @@ class QuestionAnswering(Module):
     faq_sq_empty_path = tmp_dir + "/data/问答上传模板.xlsx"
     faq_lq_empty_path = tmp_dir + "/data/语料上传模板.xlsx"
 
-    def __init__(self, app_id,set):
+    def __init__(self, app_id, set, init):
         super().__init__(app_id, 'qa',set)
         self.caller = QACaller(app_id)
+        if init:
+            self.init()
+
     def train(self, data: str = None, question_path: str = None, corpus_path: str = None,append: bool = False,show_progress:bool=True):
         """
         :param data:
@@ -208,12 +211,12 @@ class QuestionAnswering(Module):
         lq_id = self.caller.add_corpus(question_id, corpus)
         return lq_id
 
-    def delete_corpus(self, question_id, corpus_id):
+    def delete_corpus(self, corpus_id):
         """
         删除语料
         :return:
         """
-        return self.caller.delete_corpus(question_id, corpus_id)
+        return self.caller.delete_corpus(corpus_id)
 
     def add_question(self, question_data: dict):
         """
